@@ -472,8 +472,13 @@ static const R_CMethodDef CEntries[] = {
     {NULL, NULL, 0}
 };
 
+
+#include <Rversion.h>
 void R_init_MASS(DllInfo *dll)
 {
     R_registerRoutines(dll, CEntries, NULL, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
+#if defined(R_VERSION) && R_VERSION >= R_Version(2, 16, 0)
+    R_forceSymbols(dll, TRUE);
+#endif
 }
